@@ -41,7 +41,7 @@ class Easyocrpipleline:
             dictionary[result[i][1]]["score"] = result[i][2]
         json_name = file.split('/')[-1].split('.')[0]
         # json log file create
-        print("/tmp/testfolder/"+json_name)
+        print("/tmp/testfolder/"+json_name,'+++++++++++++++++++')
         with open("/tmp/testfolder/"+json_name+".json", "w") as outfile:
             json.dump(dictionary, outfile)
 
@@ -54,7 +54,9 @@ class Easyocrpipleline:
             reader (object): easy ocr object
         """
         print("+++++++e")
+        print(path)
         reader = easyocr.Reader(['en'])
+        print(reader,"-----------")
         result = reader.readtext(path,width_ths=0)
         print(result)
         self.create_json(result, path)
